@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 
-class OperatingSystem():
+class OperatingSystem(object):
     def __init__(self, data):
         self.slug = data['slug']
         self.name = data['name']
